==> batchcomputecli-0.0.17.tar.gz: batchcomputecli-0.0.17/src/batchcomputecli/actions/project/update_task.py <==
from ...services import project, client, docker,printer,oss_client
import json


def update(task_name=None, image_id=None, docker_image=None ,oss_path=None):

    project.check_is_job_project()

    with open('./job.json', 'r') as f:
        obj = json.loads(f.read())

    if not obj.get('TaskDag'):
        obj['TaskDag'] = {}
    if not obj['TaskDag'].get('TaskDescMap'):
        obj['TaskDag']['TaskDescMap'] = {}

    task_map = obj['TaskDag']['TaskDescMap']
    if task_name:
        if not task_map.get('task_name'):
            raise Exception('Not found task %s' % task_name)

    change_flag=False

    if image_id:
        update_task_value('ImageId', image_id, task_map, task_name)
        change_flag=True

    if oss_path:
        update_oss_path(oss_path, task_map, task_name)
        change_flag=True


    if docker_image and docker_image!='false':
        update_envs(docker_image, task_map, task_name)
        change_flag=True
    elif docker_image =='false':
        update_task_value('EnvironmentVariables', {}, task_map, task_name)
        change_flag=True


    if change_flag:
        #save
        with open('./job.json', 'w') as f:
            f.write(json.dumps(obj,indent=2))
        printer.done()
    else:
        print('\n  Nothing changed, type "bcs utask -h" for more information\n')



def transform_oss_path(oss_path=None):
    if oss_path:
        if not oss_path.endswith('/'):
            oss_path = oss_path+'/'
        oss_client.check(oss_path)
    return oss_path

def transform_image_id(image_id=None):
    if image_id:
        if image_id not in [n['ImageId'] for n in client.list_images()]:
            raise Exception('Invalidate ImageId: %s' % image_id)

    return image_id




def update_oss_path(oss_path, task_map, task_name=None):
    if task_name:
        task_map[task_name]['PackageUri'] = '%sworker.tar.gz' % oss_path
        task_map[task_name]['StdoutRedirectPath'] = '%slogs' % oss_path
        task_map[task_name]['StderrRedirectPath'] = '%slogs' % oss_path
    else:
        for k in task_map:
            task_map[k]['PackageUri'] = '%sworker.tar.gz' % oss_path
            task_map[k]['StdoutRedirectPath'] = '%slogs' % oss_path
            task_map[k]['StderrRedirectPath'] = '%slogs' % oss_path

def update_task_value(key, val, task_map, task_name=None):
    if not task_name:
        for k in task_map:
            task_map[k][key] = val
    else:
        task_map[task_name][key] = val


def update_envs(docker_image, task_map, task_name=None):
    info = docker.get_registry_oss_info()

    if ':' not in docker_image:
       docker_image = "localhost:%s/%s" % (info.get('port'), docker_image)

    envs = {
       "BATCH_COMPUTE_DOCKER_IMAGE": docker_image,  #localhost:32768/myubuntu
       "BATCH_COMPUTE_DOCKER_REGISTRY_OSS_PATH": "oss://%s/%s" % (info.get('OSS_BUCKET'), info.get('STORAGE_PATH')) #oss://mybucket/mydockerimages
    }


    if not task_name:
        for k in task_map:
            if not task_map[k].get('EnvironmentVariables'):
                task_map[k]['EnvironmentVariables'] = {}
            for k2 in envs:
                task_map[k]['EnvironmentVariables'][k2]=envs[k2]
    else:
        if not task_map[task_name].get('EnvironmentVariables'):
            task_map[task_name]['EnvironmentVariables'] = {}
        for k2 in envs:
            task_map[task_name]['EnvironmentVariables'][k2]=envs[k2]

==> batchcomputecli-0.0.19.tar.gz: batchcomputecli-0.0.19/src/batchcomputecli/actions/project/update_task.py <==
from ...services import project, client, docker,printer,oss_client
import json


def update(task_name=None, image_id=None, docker_image=None ,oss_path=None, mount=None):

    project.check_is_job_project()

    with open('./job.json', 'r') as f:
        obj = json.loads(f.read())

    if not obj.get('TaskDag'):
        obj['TaskDag'] = {}
    if not obj['TaskDag'].get('TaskDescMap'):
        obj['TaskDag']['TaskDescMap'] = {}



    task_map = obj['TaskDag']['TaskDescMap']

    if task_name:
        if not task_map.get(task_name):
            raise Exception('Not found task %s' % task_name)

    change_flag=False

    if image_id:
        update_task_value('ImageId', image_id, task_map, task_name)
        change_flag=True

    if oss_path:
        update_oss_path(oss_path, task_map, task_name)
        change_flag=True


    if docker_image and docker_image!='false':
        # add docker envs
        update_envs(docker_image, task_map, task_name)
        change_flag=True
    elif docker_image =='false':
        #clear EnvironmentVariables
        update_task_value('EnvironmentVariables', {}, task_map, task_name)
        change_flag=True


    if mount:
        update_task_ossmapping(mount, task_map, task_name)
        change_flag=True


    if change_flag:
        #save
        with open('./job.json', 'w') as f:
            f.write(json.dumps(obj,indent=2))
        printer.done()
    else:
        print('\n  Nothing changed, type "bcs utask -h" for more information\n')



def transform_oss_path(oss_path=None):
    if oss_path:
        if not oss_path.endswith('/'):
            oss_path = oss_path+'/'
        oss_client.check(oss_path)
    return oss_path

def transform_image_id(image_id=None):
    if image_id:
        if image_id not in [n['ImageId'] for n in client.list_images()]:
            raise Exception('Invalidate ImageId: %s' % image_id)

    return image_id



def update_task_ossmapping(mount, task_map, task_name=None):
    m = {}
    arr = mount.split(',')
    for n in arr:
        arr2 = n.split('=')
        if len(arr2)==2:
            transform_oss_path(arr2[0])
            m[arr2[0]]=arr2[1]

    if task_name:
        _update_ossMapping(task_map[task_name], m)
    else:
        for k in task_map:
            _update_ossMapping(task_map[k], m)



def _update_ossMapping(task, m):
    for k in m:
        if not task.get('OssMapping'):
            task['OssMapping']={}

        if m.get(k):
            task['OssMapping'][k] = m[k]
        else:
            if task['OssMapping'].get(k):
                task['OssMapping'].pop(k)


def update_oss_path(oss_path, task_map, task_name=None):
    if task_name:
        task_map[task_name]['PackageUri'] = '%sworker.tar.gz' % oss_path
        task_map[task_name]['StdoutRedirectPath'] = '%slogs' % oss_path
        task_map[task_name]['StderrRedirectPath'] = '%slogs' % oss_path
    else:
        for k in task_map:
            task_map[k]['PackageUri'] = '%sworker.tar.gz' % oss_path
            task_map[k]['StdoutRedirectPath'] = '%slogs' % oss_path
            task_map[k]['StderrRedirectPath'] = '%slogs' % oss_path

def update_task_value(key, val, task_map, task_name=None):
    if not task_name:
        for k in task_map:
            task_map[k][key] = val
    else:
        task_map[task_name][key] = val


def update_envs(docker_image, task_map, task_name=None):
    info = docker.get_registry_oss_info()

    if ':' not in docker_image:
       docker_image = "localhost:%s/%s" % (info.get('port'), docker_image)

    envs = {
       "BATCH_COMPUTE_DOCKER_IMAGE": docker_image,  #localhost:32768/myubuntu
       "BATCH_COMPUTE_DOCKER_REGISTRY_OSS_PATH": "oss://%s/%s" % (info.get('OSS_BUCKET'), info.get('STORAGE_PATH')) #oss://mybucket/mydockerimages
    }


    if not task_name:
        for k in task_map:
            if not task_map[k].get('EnvironmentVariables'):
                task_map[k]['EnvironmentVariables'] = {}
            for k2 in envs:
                task_map[k]['EnvironmentVariables'][k2]=envs[k2]
    else:
        if not task_map[task_name].get('EnvironmentVariables'):
            task_map[task_name]['EnvironmentVariables'] = {}
        for k2 in envs:
            task_map[task_name]['EnvironmentVariables'][k2]=envs[k2]
